summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/protocols/jabber/jingle/libjingle/talk
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/task.cc10
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/task.h14
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/taskrunner.cc2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.cc20
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.h6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.cc24
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.h8
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.cc14
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/call/status.h26
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.cc2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.cc4
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/mediachannel.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/session/phone/voicechannel.cc6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlelement.cc2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlprinter.cc2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.cc10
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h10
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h40
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.cc30
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.h36
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc8
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.cc4
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h6
28 files changed, 150 insertions, 150 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.cc b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.cc
index a5a94941..6d85cb0d 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.cc
@@ -194,12 +194,12 @@ int Task::Process(int state) {
void
Task::AddChild(Task * child) {
- children_.insert(child);
+ tqchildren_.insert(child);
}
bool
Task::AllChildrenDone() {
- for (ChildSet::iterator it = children_.begin(); it != children_.end(); ++it) {
+ for (ChildSet::iterator it = tqchildren_.begin(); it != tqchildren_.end(); ++it) {
if (!(*it)->IsDone())
return false;
}
@@ -213,8 +213,8 @@ Task::AnyChildError() {
void
Task::AbortAllChildren() {
- if (children_.size() > 0) {
- ChildSet copy = children_;
+ if (tqchildren_.size() > 0) {
+ ChildSet copy = tqchildren_;
for (ChildSet::iterator it = copy.begin(); it != copy.end(); ++it) {
(*it)->Abort(true); // Note we do not wake
}
@@ -231,7 +231,7 @@ void
Task::OnChildStopped(Task * child) {
if (child->HasError())
child_error_ = true;
- children_.erase(child);
+ tqchildren_.erase(child);
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/taskrunner.cc b/kopete/protocols/jabber/jingle/libjingle/talk/base/taskrunner.cc
index b5ecc55e..43728eb7 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/taskrunner.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/taskrunner.cc
@@ -33,7 +33,7 @@
namespace buzz {
TaskRunner::~TaskRunner() {
- // this kills and deletes children silently!
+ // this kills and deletes tqchildren silently!
AbortAllChildren();
RunTasks();
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.cc b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.cc
index 6d818932..40c1fbfe 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.cc
@@ -188,13 +188,13 @@ private:
CallClient* call_client_;
};
-const char* DescribeStatus(buzz::Status::Show show, const std::string& desc) {
+const char* DescribetqStatus(buzz::tqStatus::Show show, const std::string& desc) {
switch (show) {
- case buzz::Status::SHOW_XA: return desc.c_str();
- case buzz::Status::SHOW_ONLINE: return "online";
- case buzz::Status::SHOW_AWAY: return "away";
- case buzz::Status::SHOW_DND: return "do not disturb";
- case buzz::Status::SHOW_CHAT: return "ready to chat";
+ case buzz::tqStatus::SHOW_XA: return desc.c_str();
+ case buzz::tqStatus::SHOW_ONLINE: return "online";
+ case buzz::tqStatus::SHOW_AWAY: return "away";
+ case buzz::tqStatus::SHOW_DND: return "do not disturb";
+ case buzz::tqStatus::SHOW_CHAT: return "ready to chat";
delault: return "offline";
}
}
@@ -320,11 +320,11 @@ void CallClient::InitPresence() {
this, &CallClient::OnStatusUpdate);
presence_push_->Start();
- buzz::Status my_status;
+ buzz::tqStatus my_status;
my_status.set_jid(xmpp_client_->jid());
my_status.set_available(true);
my_status.set_invisible(false);
- my_status.set_show(buzz::Status::SHOW_ONLINE);
+ my_status.set_show(buzz::tqStatus::SHOW_ONLINE);
my_status.set_priority(0);
my_status.set_know_capabilities(true);
my_status.set_phone_capability(true);
@@ -337,7 +337,7 @@ void CallClient::InitPresence() {
presence_out_->Start();
}
-void CallClient::OnStatusUpdate(const buzz::Status& status) {
+void CallClient::OnStatusUpdate(const buzz::tqStatus& status) {
RosterItem item;
item.jid = status.jid();
item.show = status.show();
@@ -362,7 +362,7 @@ void CallClient::PrintRoster() {
while (iter != roster_->end()) {
Console()->Printf("%s - %s",
iter->second.jid.BareJid().Str().c_str(),
- DescribeStatus(iter->second.show, iter->second.status));
+ DescribetqStatus(iter->second.show, iter->second.status));
iter++;
}
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.h b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.h
index d35a6114..24ce1545 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/callclient.h
@@ -29,7 +29,7 @@
namespace buzz {
class PresencePushTask;
-class Status;
+class tqStatus;
}
namespace cricket {
@@ -43,7 +43,7 @@ class Call;
struct RosterItem {
buzz::Jid jid;
- buzz::Status::Show show;
+ buzz::tqStatus::Show show;
std::string status;
};
@@ -82,7 +82,7 @@ private:
void OnSendStanza(cricket::SessionClient *client, const buzz::XmlElement* stanza);
void InitPresence();
- void OnStatusUpdate(const buzz::Status& status);
+ void OnStatusUpdate(const buzz::tqStatus& status);
};
#endif // CRICKET_EXAMPLES_CALL_CALLCLIENT_H__
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.cc b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.cc
index a15a6c83..7fd68120 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.cc
@@ -42,27 +42,27 @@ bool ToString(const T &t,
return !oss.fail();
}
-XmppReturnStatus
-PresenceOutTask::Send(const Status & s) {
+XmppReturntqStatus
+PresenceOutTask::Send(const tqStatus & s) {
if (GetState() != STATE_INIT)
return XMPP_RETURN_BADSTATE;
- stanza_.reset(TranslateStatus(s));
+ stanza_.reset(TranslatetqStatus(s));
return XMPP_RETURN_OK;
}
-XmppReturnStatus
-PresenceOutTask::SendDirected(const Jid & j, const Status & s) {
+XmppReturntqStatus
+PresenceOutTask::SendDirected(const Jid & j, const tqStatus & s) {
if (GetState() != STATE_INIT)
return XMPP_RETURN_BADSTATE;
- XmlElement * presence = TranslateStatus(s);
+ XmlElement * presence = TranslatetqStatus(s);
presence->AddAttr(TQN_TO, j.Str());
stanza_.reset(presence);
return XMPP_RETURN_OK;
}
-XmppReturnStatus PresenceOutTask::SendProbe(const Jid & jid) {
+XmppReturntqStatus PresenceOutTask::SendProbe(const Jid & jid) {
if (GetState() != STATE_INIT)
return XMPP_RETURN_BADSTATE;
@@ -82,7 +82,7 @@ PresenceOutTask::ProcessStart() {
}
XmlElement *
-PresenceOutTask::TranslateStatus(const Status & s) {
+PresenceOutTask::TranslatetqStatus(const tqStatus & s) {
XmlElement * result = new XmlElement(TQN_PRESENCE);
if (!s.available()) {
result->AddAttr(TQN_TYPE, STR_UNAVAILABLE);
@@ -92,19 +92,19 @@ PresenceOutTask::TranslateStatus(const Status & s) {
result->AddAttr(TQN_TYPE, STR_INVISIBLE);
}
- if (s.show() != Status::SHOW_ONLINE && s.show() != Status::SHOW_OFFLINE) {
+ if (s.show() != tqStatus::SHOW_ONLINE && s.show() != tqStatus::SHOW_OFFLINE) {
result->AddElement(new XmlElement(TQN_SHOW));
switch (s.show()) {
default:
result->AddText(STR_SHOW_AWAY, 1);
break;
- case Status::SHOW_XA:
+ case tqStatus::SHOW_XA:
result->AddText(STR_SHOW_XA, 1);
break;
- case Status::SHOW_DND:
+ case tqStatus::SHOW_DND:
result->AddText(STR_SHOW_DND, 1);
break;
- case Status::SHOW_CHAT:
+ case tqStatus::SHOW_CHAT:
result->AddText(STR_SHOW_CHAT, 1);
break;
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.h b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.h
index 2b65a553..47660514 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presenceouttask.h
@@ -31,13 +31,13 @@ public:
PresenceOutTask(Task * parent) : XmppTask(parent) {}
virtual ~PresenceOutTask() {}
- XmppReturnStatus Send(const Status & s);
- XmppReturnStatus SendDirected(const Jid & j, const Status & s);
- XmppReturnStatus SendProbe(const Jid& jid);
+ XmppReturntqStatus Send(const tqStatus & s);
+ XmppReturntqStatus SendDirected(const Jid & j, const tqStatus & s);
+ XmppReturntqStatus SendProbe(const Jid& jid);
virtual int ProcessStart();
private:
- XmlElement * TranslateStatus(const Status & s);
+ XmlElement * TranslatetqStatus(const tqStatus & s);
scoped_ptr<XmlElement> stanza_;
};
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.cc b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.cc
index 31d1ae77..cee7058a 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.cc
@@ -77,7 +77,7 @@ PresencePushTask::ProcessStart() {
const XmlElement * stanza = NextStanza();
if (stanza == NULL)
return STATE_BLOCKED;
- Status s;
+ tqStatus s;
s.set_jid(Jid(stanza->Attr(TQN_FROM)));
@@ -114,23 +114,23 @@ PresencePushTask::ProcessStart() {
const XmlElement * show = stanza->FirstNamed(TQN_SHOW);
if (show == NULL || show->FirstChild() == NULL) {
- s.set_show(Status::SHOW_ONLINE);
+ s.set_show(tqStatus::SHOW_ONLINE);
}
else {
if (show->BodyText() == "away") {
- s.set_show(Status::SHOW_AWAY);
+ s.set_show(tqStatus::SHOW_AWAY);
}
else if (show->BodyText() == "xa") {
- s.set_show(Status::SHOW_XA);
+ s.set_show(tqStatus::SHOW_XA);
}
else if (show->BodyText() == "dnd") {
- s.set_show(Status::SHOW_DND);
+ s.set_show(tqStatus::SHOW_DND);
}
else if (show->BodyText() == "chat") {
- s.set_show(Status::SHOW_CHAT);
+ s.set_show(tqStatus::SHOW_CHAT);
}
else {
- s.set_show(Status::SHOW_ONLINE);
+ s.set_show(tqStatus::SHOW_ONLINE);
}
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.h b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.h
index 77459647..06c68015 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/presencepushtask.h
@@ -32,7 +32,7 @@ class PresencePushTask : public XmppTask {
public:
PresencePushTask(Task * parent) : XmppTask(parent, XmppEngine::HL_TYPE) {}
virtual int ProcessStart();
- sigslot::signal1<const Status &>SignalStatusUpdate;
+ sigslot::signal1<const tqStatus &>SignalStatusUpdate;
protected:
virtual bool HandleStanza(const XmlElement * stanza);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/status.h b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/status.h
index cab9312f..264ed725 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/status.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/call/status.h
@@ -26,9 +26,9 @@
namespace buzz {
-class Status {
+class tqStatus {
public:
- Status() :
+ tqStatus() :
pri_(0),
show_(SHOW_NONE),
available_(false),
@@ -39,7 +39,7 @@ public:
is_google_client_(false),
feedback_probation_(false) {};
- ~Status() {}
+ ~tqStatus() {}
// These are arranged in "priority order", i.e., if we see
// two statuses at the same priority but with different Shows,
@@ -86,7 +86,7 @@ public:
void set_feedback_probation(bool f) { feedback_probation_ = f; }
void set_sent_time(const std::string& time) { sent_time_ = time; }
- void UpdateWith(const Status & new_value) {
+ void UpdateWith(const tqStatus & new_value) {
if (!new_value.know_capabilities()) {
bool k = know_capabilities();
bool i = is_google_client();
@@ -105,15 +105,15 @@ public:
}
}
- bool HasQuietStatus() const {
+ bool HasQuiettqStatus() const {
if (status_.empty())
return false;
- return !(QuietStatus().empty());
+ return !(QuiettqStatus().empty());
}
// Knowledge of other clients' silly automatic status strings -
// Don't show these.
- std::string QuietStatus() const {
+ std::string QuiettqStatus() const {
if (jid_.resource().find("Psi") != std::string::npos) {
if (status_ == "Online" ||
status_.find("Auto Status") != std::string::npos)
@@ -123,18 +123,18 @@ public:
if (status_ == "Sorry, I ran out for a bit!")
return STR_EMPTY;
}
- return TrimStatus(status_);
+ return TrimtqStatus(status_);
}
- std::string ExplicitStatus() const {
- std::string result = QuietStatus();
+ std::string ExplicittqStatus() const {
+ std::string result = QuiettqStatus();
if (result.empty()) {
- result = ShowStatus();
+ result = ShowtqStatus();
}
return result;
}
- std::string ShowStatus() const {
+ std::string ShowtqStatus() const {
std::string result;
if (!available()) {
result = "Offline";
@@ -159,7 +159,7 @@ public:
return result;
}
- static std::string TrimStatus(const std::string & st) {
+ static std::string TrimtqStatus(const std::string & st) {
std::string s(st);
int j = 0;
bool collapsing = true;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.cc b/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.cc
index 7d966fb3..40e694e2 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.cc
@@ -68,6 +68,6 @@ void XmppPump::OnMessage(cricket::Message *pmsg) {
RunTasks();
}
-buzz::XmppReturnStatus XmppPump::SendStanza(const buzz::XmlElement *stanza) {
+buzz::XmppReturntqStatus XmppPump::SendStanza(const buzz::XmlElement *stanza) {
return client_->SendStanza(stanza);
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.h b/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.h
index fd6f88bb..0314b2fd 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/examples/login/xmpppump.h
@@ -62,7 +62,7 @@ public:
void OnMessage(cricket::Message *pmsg);
- buzz::XmppReturnStatus SendStanza(const buzz::XmlElement *stanza);
+ buzz::XmppReturntqStatus SendStanza(const buzz::XmlElement *stanza);
private:
buzz::XmppClient *client_;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.cc b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.cc
index f3244c54..8456a90f 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.cc
@@ -110,8 +110,8 @@ void LinphoneMediaChannel::OnPacketReceived(const void *data, int len) {
sendto(fd_, buf, len, 0, (struct sockaddr*)&sockaddr, sizeof(sockaddr));
}
-void LinphoneMediaChannel::SetPlayout(bool playout) {
- play_ = playout;
+void LinphoneMediaChannel::SetPtqlayout(bool ptqlayout) {
+ play_ = ptqlayout;
}
void LinphoneMediaChannel::SetSend(bool send) {
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.h b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.h
index 0c00be75..2639c7ac 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/linphonemediaengine.h
@@ -36,7 +36,7 @@ class LinphoneMediaChannel : public MediaChannel {
virtual void SetCodec(const char *codec);
virtual void OnPacketReceived(const void *data, int len);
- virtual void SetPlayout(bool playout);
+ virtual void SetPtqlayout(bool ptqlayout);
virtual void SetSend(bool send);
virtual float GetCurrentQuality();
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/mediachannel.h b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/mediachannel.h
index db2f9654..4a2e4560 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/mediachannel.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/mediachannel.h
@@ -41,7 +41,7 @@ class MediaChannel {
void SetInterface(NetworkInterface *iface) {network_interface_ = iface;}
virtual void SetCodec(const char *codec) = 0;
virtual void OnPacketReceived(const void *data, int len) = 0;
- virtual void SetPlayout(bool playout) = 0;
+ virtual void SetPtqlayout(bool ptqlayout) = 0;
virtual void SetSend(bool send) = 0;
virtual float GetCurrentQuality() = 0;
virtual int GetOutputLevel() = 0;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
index 24036b02..90092283 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.cc
@@ -126,12 +126,12 @@ void PortAudioMediaChannel::OnPacketReceived(const void *data, int len)
}
}
-void PortAudioMediaChannel::SetPlayout(bool playout)
+void PortAudioMediaChannel::SetPtqlayout(bool ptqlayout)
{
if (!stream_)
return;
- if (play_ && !playout) {
+ if (play_ && !ptqlayout) {
int err = Pa_StopStream(stream_);
if (err != paNoError) {
fprintf(stderr, "Error stopping PortAudio stream: %s\n", Pa_GetErrorText(err));
@@ -139,7 +139,7 @@ void PortAudioMediaChannel::SetPlayout(bool playout)
}
play_ = false;
}
- else if (!play_ && playout) {
+ else if (!play_ && ptqlayout) {
int err = Pa_StartStream(stream_);
if (err != paNoError) {
fprintf(stderr, "Error starting PortAudio stream: %s\n", Pa_GetErrorText(err));
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.h b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.h
index 95c39a1a..89922e77 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/portaudiomediaengine.h
@@ -15,7 +15,7 @@ public:
virtual void SetCodec(const char *codec);
virtual void OnPacketReceived(const void *data, int len);
- virtual void SetPlayout(bool playout);
+ virtual void SetPtqlayout(bool ptqlayout);
virtual void SetSend(bool send);
virtual float GetCurrentQuality();
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/voicechannel.cc b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/voicechannel.cc
index 58e1db60..c55ef287 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/voicechannel.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/session/phone/voicechannel.cc
@@ -168,15 +168,15 @@ void VoiceChannel::SendPacket(const void *data, size_t len) {
void VoiceChannel::ChangeState() {
if (paused_ || !enabled_ || !socket_writable_) {
- channel_->SetPlayout(false);
+ channel_->SetPtqlayout(false);
channel_->SetSend(false);
} else {
if (muted_) {
channel_->SetSend(false);
- channel_->SetPlayout(true);
+ channel_->SetPtqlayout(true);
} else {
channel_->SetSend(true);
- channel_->SetPlayout(true);
+ channel_->SetPtqlayout(true);
}
}
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlelement.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlelement.cc
index 08ccd288..a021f67a 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlelement.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlelement.cc
@@ -109,7 +109,7 @@ XmlElement::XmlElement(const XmlElement & elt) :
}
pLastAttr_ = newAttr;
- // copy children
+ // copy tqchildren
XmlChild * pChild;
XmlChild ** ppLast = &pFirstChild_;
XmlChild * newChild = NULL;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlprinter.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlprinter.cc
index e0d2c006..8e36ac02 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlprinter.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmllite/xmlprinter.cc
@@ -123,7 +123,7 @@ XmlPrinterImpl::PrintElement(const XmlElement * element) {
i += 2;
}
- // now the children
+ // now the tqchildren
const XmlChild * pchild = element->FirstChild();
if (pchild == NULL)
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.cc
index 959b6f88..fa6a14a6 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.cc
@@ -86,7 +86,7 @@ public:
void OnSocketClosed();
};
-XmppReturnStatus
+XmppReturntqStatus
XmppClient::Connect(const XmppClientSettings & settings, AsyncSocket * socket, PreXmppAuth * pre_auth) {
if (socket == NULL)
return XMPP_RETURN_BADARGUMENT;
@@ -237,7 +237,7 @@ XmppClient::ProcessResponse() {
return STATE_BLOCKED;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppClient::Disconnect() {
if (d_->socket_.get() == NULL)
return XMPP_RETURN_BADSTATE;
@@ -263,17 +263,17 @@ XmppClient::NextId() {
return d_->engine_->NextId();
}
-XmppReturnStatus
+XmppReturntqStatus
XmppClient::SendStanza(const XmlElement * stanza) {
return d_->engine_->SendStanza(stanza);
}
-XmppReturnStatus
+XmppReturntqStatus
XmppClient::SendStanzaError(const XmlElement * old_stanza, XmppStanzaError xse, const std::string & message) {
return d_->engine_->SendStanzaError(old_stanza, xse, message);
}
-XmppReturnStatus
+XmppReturntqStatus
XmppClient::SendRaw(const std::string & text) {
return d_->engine_->SendRaw(text);
}
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
index f8b4798c..fd65c39c 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
@@ -74,14 +74,14 @@ public:
XmppClient(Task * parent);
~XmppClient();
- XmppReturnStatus Connect(const XmppClientSettings & settings,
+ XmppReturntqStatus Connect(const XmppClientSettings & settings,
AsyncSocket * socket,
PreXmppAuth * preauth);
virtual Task * GetParent(int code);
virtual int ProcessStart();
virtual int ProcessResponse();
- XmppReturnStatus Disconnect();
+ XmppReturntqStatus Disconnect();
const Jid & jid();
sigslot::signal1<XmppEngine::State> SignalStateChange;
@@ -97,9 +97,9 @@ public:
std::string GetAuthCookie();
std::string NextId();
- XmppReturnStatus SendStanza(const XmlElement *stanza);
- XmppReturnStatus SendRaw(const std::string & text);
- XmppReturnStatus SendStanzaError(const XmlElement * pelOriginal,
+ XmppReturntqStatus SendStanza(const XmlElement *stanza);
+ XmppReturntqStatus SendRaw(const std::string & text);
+ XmppReturntqStatus SendStanzaError(const XmlElement * pelOriginal,
XmppStanzaError code,
const std::string & text);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
index 1497c3ec..58576328 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengine.h
@@ -66,9 +66,9 @@ enum XmppStanzaError {
XSE_UNEXPECTED_REQUEST,
};
-// XmppReturnStatus
+// XmppReturntqStatus
// This is used by API functions to synchronously return status.
-enum XmppReturnStatus {
+enum XmppReturntqStatus {
XMPP_RETURN_OK,
XMPP_RETURN_BADARGUMENT,
XMPP_RETURN_BADSTATE,
@@ -171,34 +171,34 @@ public:
// SOCKET INPUT AND OUTPUT ------------------------------------------------
//! Registers the handler for socket output
- virtual XmppReturnStatus SetOutputHandler(XmppOutputHandler *pxoh) = 0;
+ virtual XmppReturntqStatus SetOutputHandler(XmppOutputHandler *pxoh) = 0;
//! Provides socket input to the engine
- virtual XmppReturnStatus HandleInput(const char * bytes, size_t len) = 0;
+ virtual XmppReturntqStatus HandleInput(const char * bytes, size_t len) = 0;
//! Advises the engine that the socket has closed
- virtual XmppReturnStatus ConnectionClosed() = 0;
+ virtual XmppReturntqStatus ConnectionClosed() = 0;
// SESSION SETUP ---------------------------------------------------------
//! Indicates the (bare) JID for the user to use.
- virtual XmppReturnStatus SetUser(const Jid & jid)= 0;
+ virtual XmppReturntqStatus SetUser(const Jid & jid)= 0;
//! Get the login (bare) JID.
virtual const Jid & GetUser() = 0;
//! Provides different methods for credentials for login.
//! Takes ownership of this object; deletes when login is done
- virtual XmppReturnStatus SetSaslHandler(SaslHandler * h) = 0;
+ virtual XmppReturntqStatus SetSaslHandler(SaslHandler * h) = 0;
//! Sets whether TLS will be used within the connection (default true).
- virtual XmppReturnStatus SetUseTls(bool useTls) = 0;
+ virtual XmppReturntqStatus SetUseTls(bool useTls) = 0;
//! Sets an alternate domain from which we allows TLS certificates.
//! This is for use in the case where a we want to allow a proxy to
//! serve up its own certificate rather than one owned by the underlying
//! domain.
- virtual XmppReturnStatus SetTlsServerDomain(const std::string & proxy_domain) = 0;
+ virtual XmppReturntqStatus SetTlsServerDomain(const std::string & proxy_domain) = 0;
//! Gets whether TLS will be used within the connection.
virtual bool GetUseTls() = 0;
@@ -206,7 +206,7 @@ public:
//! Sets the request resource name, if any (optional).
//! Note that the resource name may be overridden by the server; after
//! binding, the actual resource name is available as part of FullJid().
- virtual XmppReturnStatus SetRequestedResource(const std::string& resource) = 0;
+ virtual XmppReturntqStatus SetRequestedResource(const std::string& resource) = 0;
//! Gets the request resource name.
virtual const std::string & GetRequestedResource() = 0;
@@ -214,12 +214,12 @@ public:
// SESSION MANAGEMENT ---------------------------------------------------
//! Set callback for state changes.
- virtual XmppReturnStatus SetSessionHandler(XmppSessionHandler* handler) = 0;
+ virtual XmppReturntqStatus SetSessionHandler(XmppSessionHandler* handler) = 0;
//! Initiates the XMPP connection.
//! After supplying connection settings, call this once to initiate,
//! (optionally) encrypt, authenticate, and bind the connection.
- virtual XmppReturnStatus Connect() = 0;
+ virtual XmppReturntqStatus Connect() = 0;
//! The current engine state.
virtual State GetState() = 0;
@@ -240,7 +240,7 @@ public:
//! Sends CloseConnection to output, and disconnects and registered
//! session handlers. After Disconnect completes, it is guaranteed
//! that no further callbacks will be made.
- virtual XmppReturnStatus Disconnect() = 0;
+ virtual XmppReturntqStatus Disconnect() = 0;
// APPLICATION USE -------------------------------------------------------
@@ -257,33 +257,33 @@ public:
//! Adds a listener for session events.
//! Stanza delivery is chained to session handlers; the first to
//! return 'true' is the last to get each stanza.
- virtual XmppReturnStatus AddStanzaHandler(XmppStanzaHandler* handler, HandlerLevel level = HL_PEEK) = 0;
+ virtual XmppReturntqStatus AddStanzaHandler(XmppStanzaHandler* handler, HandlerLevel level = HL_PEEK) = 0;
//! Removes a listener for session events.
- virtual XmppReturnStatus RemoveStanzaHandler(XmppStanzaHandler* handler) = 0;
+ virtual XmppReturntqStatus RemoveStanzaHandler(XmppStanzaHandler* handler) = 0;
//! Sends a stanza to the server.
- virtual XmppReturnStatus SendStanza(const XmlElement * pelStanza) = 0;
+ virtual XmppReturntqStatus SendStanza(const XmlElement * pelStanza) = 0;
//! Sends raw text to the server
- virtual XmppReturnStatus SendRaw(const std::string & text) = 0;
+ virtual XmppReturntqStatus SendRaw(const std::string & text) = 0;
//! Sends an iq to the server, and registers a callback for the result.
//! Returns the cookie passed to the result handler.
- virtual XmppReturnStatus SendIq(const XmlElement* pelStanza,
+ virtual XmppReturntqStatus SendIq(const XmlElement* pelStanza,
XmppIqHandler* iq_handler,
XmppIqCookie* cookie) = 0;
//! Unregisters an iq callback handler given its cookie.
//! No callback will come to this handler after it's unregistered.
- virtual XmppReturnStatus RemoveIqHandler(XmppIqCookie cookie,
+ virtual XmppReturntqStatus RemoveIqHandler(XmppIqCookie cookie,
XmppIqHandler** iq_handler) = 0;
//! Forms and sends an error in response to the given stanza.
//! Swaps to and from, sets type to "error", and adds error information
//! based on the passed code. Text is optional and may be STR_EMPTY.
- virtual XmppReturnStatus SendStanzaError(const XmlElement * pelOriginal,
+ virtual XmppReturntqStatus SendStanzaError(const XmlElement * pelOriginal,
XmppStanzaError code,
const std::string & text) = 0;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.cc
index 3d363a78..c9569524 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.cc
@@ -85,7 +85,7 @@ XmppEngineImpl::~XmppEngineImpl() {
DeleteIqCookies();
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetOutputHandler(XmppOutputHandler* output_handler) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -95,7 +95,7 @@ XmppEngineImpl::SetOutputHandler(XmppOutputHandler* output_handler) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetSessionHandler(XmppSessionHandler* session_handler) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -105,7 +105,7 @@ XmppEngineImpl::SetSessionHandler(XmppSessionHandler* session_handler) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::HandleInput(const char * bytes, size_t len) {
if (state_ < STATE_OPENING || state_ > STATE_OPEN)
return XMPP_RETURN_BADSTATE;
@@ -117,7 +117,7 @@ XmppEngineImpl::HandleInput(const char * bytes, size_t len) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::ConnectionClosed() {
if (state_ != STATE_CLOSED) {
EnterExit ee(this);
@@ -128,7 +128,7 @@ XmppEngineImpl::ConnectionClosed() {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetUseTls(bool useTls) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -138,7 +138,7 @@ XmppEngineImpl::SetUseTls(bool useTls) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetTlsServerDomain(const std::string & tls_server_domain) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -153,7 +153,7 @@ XmppEngineImpl::GetUseTls() {
return tls_needed_;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetUser(const Jid & jid) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -168,7 +168,7 @@ XmppEngineImpl::GetUser() {
return user_jid_;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetSaslHandler(SaslHandler * sasl_handler) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -177,7 +177,7 @@ XmppEngineImpl::SetSaslHandler(SaslHandler * sasl_handler) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SetRequestedResource(const std::string & resource) {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -192,7 +192,7 @@ XmppEngineImpl::GetRequestedResource() {
return requested_resource_;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::AddStanzaHandler(XmppStanzaHandler * stanza_handler,
XmppEngine::HandlerLevel level) {
if (state_ == STATE_CLOSED)
@@ -203,7 +203,7 @@ XmppEngineImpl::AddStanzaHandler(XmppStanzaHandler * stanza_handler,
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::RemoveStanzaHandler(XmppStanzaHandler * stanza_handler) {
bool found = false;
@@ -227,7 +227,7 @@ XmppEngineImpl::RemoveStanzaHandler(XmppStanzaHandler * stanza_handler) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::Connect() {
if (state_ != STATE_START)
return XMPP_RETURN_BADSTATE;
@@ -245,7 +245,7 @@ XmppEngineImpl::Connect() {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SendStanza(const XmlElement * element) {
if (state_ == STATE_CLOSED)
return XMPP_RETURN_BADSTATE;
@@ -263,7 +263,7 @@ XmppEngineImpl::SendStanza(const XmlElement * element) {
return XMPP_RETURN_OK;
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SendRaw(const std::string & text) {
if (state_ == STATE_CLOSED || login_task_.get())
return XMPP_RETURN_BADSTATE;
@@ -282,7 +282,7 @@ XmppEngineImpl::NextId() {
return ss.str();
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::Disconnect() {
if (state_ != STATE_CLOSED) {
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.h
index c36f168c..6011d9e8 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl.h
@@ -57,33 +57,33 @@ public:
// SOCKET INPUT AND OUTPUT ------------------------------------------------
//! Registers the handler for socket output
- virtual XmppReturnStatus SetOutputHandler(XmppOutputHandler *pxoh);
+ virtual XmppReturntqStatus SetOutputHandler(XmppOutputHandler *pxoh);
//! Provides socket input to the engine
- virtual XmppReturnStatus HandleInput(const char * bytes, size_t len);
+ virtual XmppReturntqStatus HandleInput(const char * bytes, size_t len);
//! Advises the engine that the socket has closed
- virtual XmppReturnStatus ConnectionClosed();
+ virtual XmppReturntqStatus ConnectionClosed();
// SESSION SETUP ---------------------------------------------------------
//! Indicates the (bare) JID for the user to use.
- virtual XmppReturnStatus SetUser(const Jid & jid);
+ virtual XmppReturntqStatus SetUser(const Jid & jid);
//! Get the login (bare) JID.
virtual const Jid & GetUser();
//! Indicates the autentication to use. Takes ownership of the object.
- virtual XmppReturnStatus SetSaslHandler(SaslHandler * sasl_handler);
+ virtual XmppReturntqStatus SetSaslHandler(SaslHandler * sasl_handler);
//! Sets whether TLS will be used within the connection (default true).
- virtual XmppReturnStatus SetUseTls(bool useTls);
+ virtual XmppReturntqStatus SetUseTls(bool useTls);
//! Sets an alternate domain from which we allows TLS certificates.
//! This is for use in the case where a we want to allow a proxy to
//! serve up its own certificate rather than one owned by the underlying
//! domain.
- virtual XmppReturnStatus SetTlsServerDomain(const std::string & proxy_domain);
+ virtual XmppReturntqStatus SetTlsServerDomain(const std::string & proxy_domain);
//! Gets whether TLS will be used within the connection.
virtual bool GetUseTls();
@@ -91,7 +91,7 @@ public:
//! Sets the request resource name, if any (optional).
//! Note that the resource name may be overridden by the server; after
//! binding, the actual resource name is available as part of FullJid().
- virtual XmppReturnStatus SetRequestedResource(const std::string& resource);
+ virtual XmppReturntqStatus SetRequestedResource(const std::string& resource);
//! Gets the request resource name.
virtual const std::string & GetRequestedResource();
@@ -99,12 +99,12 @@ public:
// SESSION MANAGEMENT ---------------------------------------------------
//! Set callback for state changes.
- virtual XmppReturnStatus SetSessionHandler(XmppSessionHandler* handler);
+ virtual XmppReturntqStatus SetSessionHandler(XmppSessionHandler* handler);
//! Initiates the XMPP connection.
//! After supplying connection settings, call this once to initiate,
//! (optionally) encrypt, authenticate, and bind the connection.
- virtual XmppReturnStatus Connect();
+ virtual XmppReturntqStatus Connect();
//! The current engine state.
virtual State GetState() { return state_; }
@@ -125,40 +125,40 @@ public:
//! Sends CloseConnection to output, and disconnects and registered
//! session handlers. After Disconnect completes, it is guaranteed
//! that no further callbacks will be made.
- virtual XmppReturnStatus Disconnect();
+ virtual XmppReturntqStatus Disconnect();
// APPLICATION USE -------------------------------------------------------
//! Adds a listener for session events.
//! Stanza delivery is chained to session handlers; the first to
//! return 'true' is the last to get each stanza.
- virtual XmppReturnStatus AddStanzaHandler(XmppStanzaHandler* handler,
+ virtual XmppReturntqStatus AddStanzaHandler(XmppStanzaHandler* handler,
XmppEngine::HandlerLevel level);
//! Removes a listener for session events.
- virtual XmppReturnStatus RemoveStanzaHandler(XmppStanzaHandler* handler);
+ virtual XmppReturntqStatus RemoveStanzaHandler(XmppStanzaHandler* handler);
//! Sends a stanza to the server.
- virtual XmppReturnStatus SendStanza(const XmlElement * pelStanza);
+ virtual XmppReturntqStatus SendStanza(const XmlElement * pelStanza);
//! Sends raw text to the server
- virtual XmppReturnStatus SendRaw(const std::string & text);
+ virtual XmppReturntqStatus SendRaw(const std::string & text);
//! Sends an iq to the server, and registers a callback for the result.
//! Returns the cookie passed to the result handler.
- virtual XmppReturnStatus SendIq(const XmlElement* pelStanza,
+ virtual XmppReturntqStatus SendIq(const XmlElement* pelStanza,
XmppIqHandler* iq_handler,
XmppIqCookie* cookie);
//! Unregisters an iq callback handler given its cookie.
//! No callback will come to this handler after it's unregistered.
- virtual XmppReturnStatus RemoveIqHandler(XmppIqCookie cookie,
+ virtual XmppReturntqStatus RemoveIqHandler(XmppIqCookie cookie,
XmppIqHandler** iq_handler);
//! Forms and sends an error in response to the given stanza.
//! Swaps to and from, sets type to "error", and adds error information
//! based on the passed code. Text is optional and may be STR_EMPTY.
- virtual XmppReturnStatus SendStanzaError(const XmlElement * pelOriginal,
+ virtual XmppReturntqStatus SendStanzaError(const XmlElement * pelOriginal,
XmppStanzaError code,
const std::string & text);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
index cdcfa9e7..38f268b9 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppengineimpl_iq.cc
@@ -54,7 +54,7 @@ private:
};
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SendIq(const XmlElement * element, XmppIqHandler * iq_handler,
XmppIqCookie* cookie) {
if (state_ == STATE_CLOSED)
@@ -85,7 +85,7 @@ XmppEngineImpl::SendIq(const XmlElement * element, XmppIqHandler * iq_handler,
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::RemoveIqHandler(XmppIqCookie cookie,
XmppIqHandler ** iq_handler) {
@@ -199,7 +199,7 @@ AddErrorCode(XmlElement * error_element, XmppStanzaError code) {
}
-XmppReturnStatus
+XmppReturntqStatus
XmppEngineImpl::SendStanzaError(const XmlElement * element_original,
XmppStanzaError code,
const std::string & text) {
@@ -223,7 +223,7 @@ XmppEngineImpl::SendStanzaError(const XmlElement * element_original,
error_element.AddAttr(name, attribute->Value());
}
- // copy children
+ // copy tqchildren
for (const XmlChild * child = element_original->FirstChild();
child;
child = child->NextChild()) {
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.cc b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.cc
index c9d86ba6..e7ac0e04 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.cc
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.cc
@@ -55,14 +55,14 @@ XmppTask::StopImpl() {
}
}
-XmppReturnStatus
+XmppReturntqStatus
XmppTask::SendStanza(const XmlElement * stanza) {
if (client_ == NULL)
return XMPP_RETURN_BADSTATE;
return client_->SendStanza(stanza);
}
-XmppReturnStatus
+XmppReturntqStatus
XmppTask::SendStanzaError(const XmlElement * element_original,
XmppStanzaError code,
const std::string & text) {
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
index 0bd7c4b8..a1ed3dd3 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
@@ -78,9 +78,9 @@ public:
protected:
friend class XmppClient;
- XmppReturnStatus SendStanza(const XmlElement * stanza);
- XmppReturnStatus SetResult(const std::string & code);
- XmppReturnStatus SendStanzaError(const XmlElement * element_original,
+ XmppReturntqStatus SendStanza(const XmlElement * stanza);
+ XmppReturntqStatus SetResult(const std::string & code);
+ XmppReturntqStatus SendStanzaError(const XmlElement * element_original,
XmppStanzaError code,
const std::string & text);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
index 5a486198..7140b691 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
@@ -61,13 +61,13 @@
// might be working on something as you send it infomration, you may want
// to have a queue in the task.
//
// (3) Finally it helps manage parent tasks and children. If a parent
// task gets aborted, all the children tasks are too. The nice thing
// about this, for example, is if you have one parent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
// of infinite lifetime child tasks and now worry about cleaning them up.
// When the parent task goes to STATE_DONE, the task engine will make
// sure all those children are aborted and get deleted.
//
// Notice that Task has a few built-in states, e.g.,
//
@@ -122,7 +122,7 @@ public:
// Called from outside to stop task without any more callbacks
void Abort(bool nowake = false);
// For managing children
bool AllChildrenDone();
bool AnyChildError();
@@ -153,7 +153,7 @@ protected:
virtual int ProcessStart() = 0;
virtual int ProcessResponse() { return STATE_DONE; }
// for managing children (if any)
void AddChild(Task * child);
void AbortAllChildren();
@@ -172,9 +172,9 @@ private:
bool child_error_;
unsigned long long start_time_;
// for managing children
typedef std::set<Task *> ChildSet;
- ChildSet children_;
+ ChildSet tqchildren_;
};
@@ -61,13 +61,13 @@
// to have a queue in the task.
//
-// (3) Finally it helps manage parent tasks and children. If a parent
-// task gets aborted, all the children tasks are too. The nice thing
+// (3) Finally it helps manage parent tasks and tqchildren. If a parent
+// task gets aborted, all the tqchildren tasks are too. The nice thing
// about this, for example, is if you have one parent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
@@ -61,13 +61,13 @@
// of infinite lifetime child tasks and now worry about cleaning them up.
// When the parent task goes to STATE_DONE, the task engine will make
-// sure all those children are aborted and get deleted.
+// sure all those tqchildren are aborted and get deleted.
//
// Notice that Task has a few built-in states, e.g.,
@@ -122,7 +122,7 @@ public:
// Called from outside to stop task without any more callbacks
void Abort(bool nowake = false);
- // For managing children
+ // For managing tqchildren
bool AllChildrenDone();
bool AnyChildError();
@@ -153,7 +153,7 @@ protected:
virtual int ProcessStart() = 0;
virtual int ProcessResponse() { return STATE_DONE; }
- // for managing children (if any)
+ // for managing tqchildren (if any)
void AddChild(Task * child);
void AbortAllChildren();
@@ -172,9 +172,9 @@ private:
bool child_error_;
unsigned long long start_time_;
- // for managing children
+ // for managing tqchildren
typedef std::set<Task *> ChildSet;